==> sqlc-1.1.0.zip: clib/cmd/base/CommandBase.java <==
/*
 * ********************************************************************
 * SQLC Release 1.1.0
 * ********************************************************************
 */
package clib.cmd.base;

import clib.com.*;


/**
 * sR}hW
 *
 * @since     JDK1.1
 * @author    dynaworks
 */
public abstract  class CommandBase
{
    // ********************************
    // 
    // ********************************
    /** s */
    protected ExecuteCtx ctx;
    /** R}h */
    protected String command_name;
    /** IvV */
    protected String command_option;
    /** sR}h */
    protected String command_string;


    /*******************************************************************
     * \z
     ******************************************************************/
    public CommandBase()
    {
        ctx = new ExecuteCtx();
        command_name = new String();
        command_option = new String();
        command_string = new String();
    }

    /*******************************************************************
     * \z(ʍ\z)
     * @param bean sR}hW
     ******************************************************************/
    public CommandBase(CommandBase bean)
    {
        this.ctx = new ExecuteCtx(bean.ctx);
        this.command_name = new String(bean.command_name);
        this.command_option = new String(bean.command_option);
        this.command_string = new String(bean.command_string);
    }

    /*******************************************************************
     * \z
     * @param ExecuteCtx s
     ******************************************************************/
    public CommandBase(ExecuteCtx ctx)
    {
        this.ctx = ctx;
    }


    /*******************************************************************
     * s̎擾
     * @return  s
     ******************************************************************/
    public ExecuteCtx getExecuteCtx()
    {
        return ctx;
    }
    /*******************************************************************
     * s̐ݒ
     * @param   ctx s
     ******************************************************************/
    public void setExecuteCtx(ExecuteCtx ctx)
    {
        this.ctx = ctx;
    }

    /*******************************************************************
     * R}h̎擾
     * @return  R}h
     ******************************************************************/
    public String getCommandName()
    {
        return command_name;
    }
    /*******************************************************************
     * R}h̐ݒ
     * @param   command_name R}h
     ******************************************************************/
    public void setCommandName(String command_name)
    {
        this.command_name = command_name;
    }

    /*******************************************************************
     * IvV̎擾
     * @return  IvV
     ******************************************************************/
    public String getCommandOption()
    {
        return command_option;
    }
    /*******************************************************************
     * IvV̐ݒ
     * @param   command_option IvV
     ******************************************************************/
    public void setCommandOption(String command_option)
    {
        this.command_option = command_option;
    }

    /*******************************************************************
     * sR}h̎擾
     * @return  sR}h
     ******************************************************************/
    public String getCommandString()
    {
        return command_string;
    }
    /*******************************************************************
     * sR}h̐ݒ
     * @param   command_string sR}h
     ******************************************************************/
    public void setCommandString(String command_string)
    {
        this.command_string = command_string;
    }
    /*******************************************************************
     * s
     * @param ExecuteCtx s
     * @return :TRUE, s:FALSE
     ******************************************************************/
    public abstract boolean execute(ExecuteCtx ctx);



}

==> sqlc-1.3.0.zip: clib/cmd/base/CommandBase.java <==
package clib.cmd.base;

import java.text.*;
import java.util.*;

import clib.com.*;


/**
 * sR}hW
 *
 * @since     JDK1.1
 * @author    dynaworks
 */
public abstract  class CommandBase
{
    // ********************************
    // 
    // ********************************
    /** sR}h */
    protected String command_string;

    /*******************************************************************
     * \z
     ******************************************************************/
    public CommandBase()
    {
        command_string = new String();
    }

    /*******************************************************************
     * sR}h̎擾
     * @return  sR}h
     ******************************************************************/
    public String getCommandString()
    {
        return command_string;
    }

    /*******************************************************************
     * sR}h̎擾
     * @return  sR}h
     ******************************************************************/
    public String[] getCommandStringParams()
    {
        String[] aryParam = null;
        Vector varParam = new Vector();
        StringTokenizer st = new StringTokenizer(getCommandString());
        while (st.hasMoreTokens())
        {
            varParam.addElement(st.nextToken());
        }
        aryParam = new String[varParam.size()];
        varParam.copyInto(aryParam);
        return aryParam;
    }

    /*******************************************************************
     * sR}h̐ݒ
     * @param   command_string sR}h
     ******************************************************************/
    public void setCommandString(String command_string)
    {
        this.command_string = command_string;
    }
    /*******************************************************************
     * s
     * @param ExecuteCtx s
     * @return :TRUE, s:FALSE
     ******************************************************************/
    public abstract boolean execute(ExecuteCtx ctx);

}
